{#
# This file is part of Invenio.
# Copyright (C) 2012, 2013, 2014, 2015, 2016 CERN.
#
# Invenio is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License as
# published by the Free Software Foundation; either version 2 of the
# License, or (at your option) any later version.
#
# Invenio is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with Invenio; if not, write to the Free Software Foundation, Inc.,
# 59 Temple Place, Suite 330, Boston, MA 02111-1307, USA.
#}

{%- extends config.WORKFLOWS_UI_BASE_TEMPLATE %}

{% block page_body %}
  <div class="container search-page">
    <div class="row">
      <div class="col-md-12">
        <h2>Detailed information about {{ workflow_object.id }}</h2>
        {% if workflow_object.data.title_statement %}
            <h4><a target="_self" ng-href="/workflows/{{ workflow_object.id }}">{{ workflow_object.data.title_statement.title }}</a></h4>
        {% endif %}
        {% if workflow_object.data.summary %}
            <p class="lead">{{ workflow_object.data.summary.summary }}</p>
        {% endif %}
      </div>
    </div>
    <div class="row">
      <div class="col-md-12">
        <pre>{{ workflow_object.data }}</pre>
      </div>
    </div>
  </div>
{% endblock %}
